summaryrefslogtreecommitdiff
path: root/Master
diff options
context:
space:
mode:
Diffstat (limited to 'Master')
-rwxr-xr-xMaster/texmf-dist/scripts/texlive/tlmgr.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/Master/texmf-dist/scripts/texlive/tlmgr.pl b/Master/texmf-dist/scripts/texlive/tlmgr.pl
index 4868c05e5db..1f1b5e8dbee 100755
--- a/Master/texmf-dist/scripts/texlive/tlmgr.pl
+++ b/Master/texmf-dist/scripts/texlive/tlmgr.pl
@@ -4004,8 +4004,8 @@ sub action_option {
}
}
} else {
- if ($what eq "location") {
- # rewrite location -> repository
+ if ($what eq "location" || $what eq "repo") {
+ # silently rewrite location|repo -> repository
$what = "repository";
}
my $found = 0;